%% Estimate as a function of feedback
% This function keeps the prior the same while varying the likelihood.
% Incidentally this is the same that would happen if we had two likelihoods
% only then we should use the name likelihood instead of prior
x=-10:0.1:10 % the range used for calculations
feedbacks=-8:.2:8 % potential places for visual feedback

% here we assume that the prior is fixed and given
muPrior=1;
sigmaPrior=1.5;
prior=exp(-(x-muPrior).^2/(2*sigmaPrior^2));
prior=prior/sum(prior);

for i=1:length(feedbacks) % vary the positions where feedback may be given
    plot(x,prior,'g'); % plot the prior
    hold on
    
    %choose a feedback position and plot the likelihood
    muLikelihood=feedbacks(i);
    sigmaLikelihood=1;
    likelihood=exp(-(x-muLikelihood).^2/(2*sigmaLikelihood^2));
    likelihood=likelihood/sum(likelihood);
    plot(x,likelihood,'r');
    
    %calculate the posterior and plot it
    posterior=prior.*likelihood;
    posterior=posterior/(sum(posterior));
    meanPosterior(i)=sum(posterior.*x);
    plot(x,posterior,'y');
    
    hold off
    pause(0.2); % have a little break so we can see what happens
end
figure
plot(feedbacks,meanPosterior)
xlabel('feedback position');
ylabel('best estimate');
